==> mipkit-1.6.4-py3-none-any.whl: mipkit/logger.py <==
"""
The MIT License (MIT)
Copyright (c) 2021 Cong Vo

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

Provided license texts might have their own copyrights and restrictions

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
"""
import logging
import warnings

try:
    from termcolor import colored, cprint
except ImportError as e:
    warnings.warn(e.msg)


def get_logger():
    logger = logging.getLogger()
    logger.setLevel(level=logging.INFO)
    formatter = logging.Formatter(
        "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
    )
    ch = logging.StreamHandler()
    ch.setFormatter(formatter)
    logger.addHandler(ch)
    return logger


def mprint(*args):
    return " ".join(map(str, *args))


def turn_yellow(message):
    return colored(message, "yellow")


def turn_red(message):
    return colored(message, "red")


def turn_green(message):
    return colored(message, "green")


def print_warning(*args):
    message = mprint(args)
    cprint("[WARNING] " + message, color="yellow")


def print_info(*args):
    message = mprint(args)
    cprint("[INFO] " + message, color="green")


def print_error(*args):
    message = mprint(args)
    cprint("[ERROR] " + message, color="red")


def print_debug_note(*args):
    message = mprint(args)
    cprint("[DEBUG] " + message, color="blue")

==> mipkit-1.7.0-py3-none-any.whl: mipkit/logger.py <==
"""
The MIT License (MIT)
Copyright (c) 2021 Cong Vo

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

Provided license texts might have their own copyrights and restrictions

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
"""
import logging
import warnings

try:
    from termcolor import colored, cprint
except ImportError as e:
    warnings.warn(e.msg)


def get_logger():
    logger = logging.getLogger()
    logger.setLevel(level=logging.INFO)
    formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
    ch = logging.StreamHandler()
    ch.setFormatter(formatter)
    logger.addHandler(ch)
    return logger


def mprint(*args):
    return " ".join(map(str, *args))


def turn_yellow(message):
    return colored(message, "yellow")


def turn_red(message):
    return colored(message, "red")


def turn_green(message):
    return colored(message, "green")


def print_warning(*args):
    message = mprint(args)
    cprint("[WARNING] " + message, color="yellow")


def print_info(*args):
    message = mprint(args)
    cprint("[INFO] " + message, color="green")


def print_error(*args):
    message = mprint(args)
    cprint("[ERROR] " + message, color="red")


def print_debug_note(*args):
    message = mprint(args)
    cprint("[DEBUG] " + message, color="blue")
